pub struct NamespaceProof {
proof: Option<NonEmptyNamespaceProof>,
}Expand description
Information required to verify a payload.
Fields
proof: Option<NonEmptyNamespaceProof>Implementations
Sourceimpl NamespaceProof
impl NamespaceProof
Sourcepub fn new(proof: NsProof, common: VidCommon) -> Self
pub fn new(proof: NsProof, common: VidCommon) -> Self
Construct a NamespaceProof.
Takes the underlying NsProof, plus corresponding VidCommon data to allow a client to
verify the proof.
Sourcepub fn not_present() -> Self
pub fn not_present() -> Self
Create a trivial proof for a namespace which is not present in a given block.
Sourcepub fn verify(
&self,
header: &Header,
namespace: NamespaceId,
) -> Result<Vec<Transaction>>
pub fn verify( &self, header: &Header, namespace: NamespaceId, ) -> Result<Vec<Transaction>>
Verify a NamespaceProof.
If the data in this proof matches the expected header and belongs to namespace, the list
of transactions from the namespace is returned.